@@ -42,7 +42,9 @@ using namespace KCalUtils;
 #include <KAboutData>
 #include <KToolBar>
 #include <KActionCollection>
+#ifdef HAVE_GLOBAL_ACCEL_SUPPORT
 #include <KGlobalAccel>
+#endif
 #include <KStandardAction>
 #include <KLocalizedString>
 #include <KSharedConfig>
@@ -72,6 +74,7 @@ using namespace KCalUtils;
 #include <QMenuBar>
 #include <QSystemTrayIcon>
 #include <QMimeData>
+using namespace Qt::Literals::StringLiterals;
 
 using namespace KAlarmCal;
 
@@ -80,8 +83,8 @@ using namespace KAlarmCal;
 namespace
 {
 const QString UI_FILE(QStringLiteral("kalarmui.rc"));
-const QLatin1String WINDOW_NAME("MainWindow");
-const QLatin1String VIEW_GROUP("View");
+const QLatin1StringView WINDOW_NAME("MainWindow");
+const QLatin1StringView VIEW_GROUP("View");
 
 const char*   SHOW_COLUMNS        = "ShowColumns";
 const char*   SHOW_ARCHIVED_KEY   = "ShowArchivedAlarms";
@@ -126,7 +129,7 @@ MainWindow::MainWindow(bool restored)
     qCDebug(KALARM_LOG) << "MainWindow:";
     setAttribute(Qt::WA_DeleteOnClose);
     setWindowModality(Qt::WindowModal);
-    setObjectName(QLatin1StringView("MainWin"));    // used by LikeBack
+    setObjectName("MainWin"_L1);    // used by LikeBack
     setPlainCaption(KAboutData::applicationData().displayName());
     KConfigGroup config(KSharedConfig::openConfig(), VIEW_GROUP);
     mShowResources     = config.readEntry(SHOW_RESOURCES_KEY, false);
@@ -281,7 +284,7 @@ MainWindow* MainWindow::mainMainWindow()
 */
 bool MainWindow::isTrayParent() const
 {
-    TrayWindow* tray = theApp()->trayWindow();
+    const TrayWindow* tray = theApp()->trayWindow();
     if (!tray  ||  !QSystemTrayIcon::isSystemTrayAvailable())
         return false;
     if (tray->assocMainWindow() == this)
@@ -514,7 +517,9 @@ void MainWindow::initActions()
 
     QAction* action = KAlarm::createStopPlayAction(this);
     actions->addAction(QStringLiteral("stopAudio"), action);
+#ifdef HAVE_GLOBAL_ACCEL_SUPPORT
     KGlobalAccel::setGlobalShortcut(action, QList<QKeySequence>());  // allow user to set a global shortcut
+#endif
 
     mActionShowArchived = new KToggleAction(i18nc("@action", "Show Archived Alarms"), this);
     actions->addAction(QStringLiteral("showArchivedAlarms"), mActionShowArchived);
@@ -537,7 +542,9 @@ void MainWindow::initActions()
     {
         mActionSpreadWindows = KAlarm::createSpreadWindowsAction(this);
         actions->addAction(QStringLiteral("spread"), mActionSpreadWindows);
+#ifdef HAVE_GLOBAL_ACCEL_SUPPORT
         KGlobalAccel::setGlobalShortcut(mActionSpreadWindows, QList<QKeySequence>());  // allow user to set a global shortcut
+#endif
     }
 
     mActionImportAlarms = new QAction(i18nc("@action", "Import Alarms..."), this);
@@ -589,19 +596,20 @@ void MainWindow::initActions()
     actions->setDefaultShortcuts(mActionRedo, redoShortcut);
     connect(mActionRedo, &KToolBarPopupAction::triggered, this, &MainWindow::slotRedo);
 
-    KStandardAction::find(mListView, &EventListView::slotFind, actions);
-    mActionFindNext = KStandardAction::findNext(mListView, &EventListView::slotFindNext, actions);
-    mActionFindPrev = KStandardAction::findPrev(mListView, &EventListView::slotFindPrev, actions);
-    KStandardAction::selectAll(mListView, &QTreeView::selectAll, actions);
-    KStandardAction::deselect(mListView, &QAbstractItemView::clearSelection, actions);
+    KStandardActions::find(mListView, &EventListView::slotFind, actions);
+    mActionFindNext = KStandardActions::findNext(mListView, &EventListView::slotFindNext, actions);
+    mActionFindPrev = KStandardActions::findPrev(mListView, &EventListView::slotFindPrev, actions);
+    KStandardActions::selectAll(mListView, &QTreeView::selectAll, actions);
+    KStandardActions::deselect(mListView, &QAbstractItemView::clearSelection,
+                               actions);
     // Quit only once the event loop is called; otherwise, the parent window will
     // be deleted while still processing the action, resulting in a crash.
     QAction* act = KStandardAction::quit(nullptr, nullptr, actions);
     connect(act, &QAction::triggered, this, &MainWindow::slotQuit, Qt::QueuedConnection);
-    KStandardAction::keyBindings(this, &MainWindow::slotConfigureKeys, actions);
-    KStandardAction::configureNotifications(this, &MainWindow::slotConfigureNotifications, actions);
-    KStandardAction::configureToolbars(this, &MainWindow::slotConfigureToolbar, actions);
-    KStandardAction::preferences(this, &MainWindow::slotPreferences, actions);
+    KStandardActions::keyBindings(this, &MainWindow::slotConfigureKeys, actions);
+    KStandardActions::configureNotifications(this, &MainWindow::slotConfigureNotifications, actions);
+    KStandardActions::configureToolbars(this, &MainWindow::slotConfigureToolbar, actions);
+    KStandardActions::preferences(this, &MainWindow::slotPreferences, actions);
     mActionShowMenuBar = KStandardAction::showMenubar(this, &MainWindow::slotToggleMenubar, actions);
     mHamburgerMenu = KStandardAction::hamburgerMenu(nullptr, nullptr, actions);
     mHamburgerMenu->setShowMenuBarAction(mActionShowMenuBar);
@@ -618,7 +626,7 @@ void MainWindow::initActions()
     applyMainWindowSettings(KSharedConfig::openConfig()->group(WINDOW_NAME));
 
     mContextMenu = static_cast<QMenu*>(factory()->container(QStringLiteral("listContext"), this));
-    QMenu* actionsMenu = static_cast<QMenu*>(factory()->container(QStringLiteral("actions"), this));
+    const QMenu* actionsMenu = static_cast<QMenu*>(factory()->container(QStringLiteral("actions"), this));
     mMenuError = (!mContextMenu  ||  !actionsMenu  ||  !resourceContextMenu());
     connect(mActionUndo->popupMenu(), &QMenu::aboutToShow, this, &MainWindow::slotInitUndoMenu);
     connect(mActionUndo->popupMenu(), &QMenu::triggered, this, &MainWindow::slotUndoItem);
@@ -676,7 +684,7 @@ void MainWindow::slotInitHamburgerMenu()
     menu->addAction(actions->action(QStringLiteral("showArchivedAlarms")));
     menu->addAction(actions->action(QStringLiteral("showDateSelector")));
     menu->addSeparator();
-    menu->addAction(actions->action(KStandardAction::name(KStandardAction::Quit)));
+    menu->addAction(actions->action(KStandardActions::name(KStandardActions::Quit)));
     mHamburgerMenu->setMenu(menu);
 }
 
@@ -1411,7 +1419,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
     AlarmText          alarmText;
     MemoryCalendar::Ptr calendar(new MemoryCalendar(Preferences::timeSpecAsZone()));
 #ifndef NDEBUG
-    const QString fmts = data->formats().join(QLatin1String(", "));
+    const QString fmts = data->formats().join(", "_L1);
     qCDebug(KALARM_LOG) << "MainWindow::executeDropEvent:" << fmts;
 #endif
 
@@ -1514,7 +1522,7 @@ void MainWindow::executeDropEvent(MainWindow* win, QDropEvent* e)
             // Try to find the mime type of the file, without downloading a remote file
             QMimeDatabase mimeDb;
             const QString mimeTypeName = mimeDb.mimeTypeForUrl(url).name();
-            action = mimeTypeName.startsWith(QLatin1String("audio/")) ? KAEvent::SubAction::Audio : KAEvent::SubAction::File;
+            action = mimeTypeName.startsWith("audio/"_L1) ? KAEvent::SubAction::Audio : KAEvent::SubAction::File;
             alarmText.setText(url.toDisplayString());
         }
     }
@@ -1584,8 +1592,8 @@ void MainWindow::slotSelection()
 {
     // Find which events have been selected
     QList<KAEvent> events = mListView->selectedEvents();
-    int count = events.count();
-    if (!count)
+    const int evCount = events.count();
+    if (!evCount)
     {
         selectionCleared();    // disable actions
         Q_EMIT selectionChanged();
@@ -1602,7 +1610,7 @@ void MainWindow::slotSelection()
     bool enableEnable = false;
     bool enableDisable = false;
     const KADateTime now = KADateTime::currentUtcDateTime();
-    for (int i = 0;  i < count;  ++i)
+    for (int i = 0;  i < evCount;  ++i)
     {
         const KAEvent ev = ResourcesCalendar::event(EventId(events.at(i)));   // get up-to-date status
         const KAEvent& event = ev.isValid() ? ev : events[i];
@@ -1629,11 +1637,11 @@ void MainWindow::slotSelection()
     }
 
     qCDebug(KALARM_LOG) << "MainWindow::slotSelection: true";
-    mActionCreateTemplate->setEnabled((count == 1) && !Resources::enabledResources(CalEvent::TEMPLATE, true).isEmpty());
+    mActionCreateTemplate->setEnabled((evCount == 1) && !Resources::enabledResources(CalEvent::TEMPLATE, true).isEmpty());
     mActionExportAlarms->setEnabled(true);
     mActionExport->setEnabled(true);
-    mActionCopy->setEnabled(active && count == 1);
-    mActionModify->setEnabled(count == 1);
+    mActionCopy->setEnabled(active && evCount == 1);
+    mActionModify->setEnabled(evCount == 1);
     mActionDelete->setEnabled(!readOnly && (active || allArchived));
     mActionReactivate->setEnabled(active && enableReactivate);
     mActionEnable->setEnabled(active && !readOnly && (enableEnable || enableDisable));
