@@ -52,6 +52,7 @@
 #include <QCloseEvent>
 #include <QScreen>
 #include <QStyle>
+using namespace Qt::Literals::StringLiterals;
 
 #include "kmailinterface.h"
 
@@ -64,8 +65,8 @@ enum FullScreenType { NoFullScreen = 0, FullScreen = 1, FullScreenActive = 2 };
 FullScreenType haveFullScreenWindow(int screen);
 FullScreenType findFullScreenWindows(const QList<QRect>& screenRects, QList<FullScreenType>& screenTypes);
 
-const QLatin1String KMAIL_DBUS_SERVICE("org.kde.kmail");
-const QLatin1String KMAIL_DBUS_PATH("/KMail");
+const QLatin1StringView KMAIL_DBUS_SERVICE("org.kde.kmail");
+const QLatin1StringView KMAIL_DBUS_PATH("/KMail");
 
 // The delay for enabling message window buttons if a zero delay is
 // configured, i.e. the windows are placed far from the cursor.
@@ -84,7 +85,7 @@ const Qt::WidgetAttribute WidgetFlags = Qt::WA_DeleteOnClose;
 class MessageText : public KTextEdit
 {
 public:
-    MessageText(QWidget* parent = nullptr)
+    explicit MessageText(QWidget* parent = nullptr)
         : KTextEdit(parent)
     {
         setReadOnly(true);
@@ -123,7 +124,7 @@ MessageWindow::MessageWindow(const KAEvent& event, const KAAlarm& alarm, int fla
     qCDebug(KALARM_LOG) << "MessageWindow():" << mEventId();
     setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags));
     setWindowModality(Qt::WindowModal);
-    setObjectName(QLatin1StringView("MessageWindow"));    // used by LikeBack
+    setObjectName("MessageWindow"_L1);    // used by LikeBack
     if (!(flags & (NoInitView | AlwaysHide)))
         MessageWindow::setUpDisplay();   // avoid calling virtual method from constructor
 
@@ -155,7 +156,7 @@ MessageWindow::MessageWindow(const KAEvent& event, const DateTime& alarmDateTime
     qCDebug(KALARM_LOG) << "MessageWindow(errmsg)";
     setAttribute(static_cast<Qt::WidgetAttribute>(WidgetFlags));
     setWindowModality(Qt::WindowModal);
-    setObjectName(QLatin1StringView("ErrorWin"));    // used by LikeBack
+    setObjectName("ErrorWin"_L1);    // used by LikeBack
     getWorkAreaAndModal();
     MessageWindow::setUpDisplay();   // avoid calling virtual method from constructor
 
@@ -175,7 +176,7 @@ MessageWindow::MessageWindow()
     qCDebug(KALARM_LOG) << "MessageWindow(): restore";
     setAttribute(WidgetFlags);
     setWindowModality(Qt::WindowModal);
-    setObjectName(QLatin1StringView("RestoredMsgWin"));    // used by LikeBack
+    setObjectName("RestoredMsgWin"_L1);    // used by LikeBack
     getWorkAreaAndModal();
 
     connect(mHelper, &MessageDisplayHelper::textsChanged, this, &MessageWindow::textsChanged);
@@ -477,7 +478,7 @@ void MessageWindow::setUpDisplay()
     // KAlarm button
     mKAlarmButton = new PushButton(topWidget);
     mKAlarmButton->setIcon(QIcon::fromTheme(KAboutData::applicationData().componentName()));
-    connect(mKAlarmButton, &QAbstractButton::clicked, this, &MessageWindow::displayMainWindow);
+    connect(mKAlarmButton, &QAbstractButton::clicked, this, [this]() { MessageWindow::displayMainWindow(); });
     grid->addWidget(mKAlarmButton, 0, gridIndex++, Qt::AlignHCenter);
     mKAlarmButton->setToolTip(xi18nc("@info:tooltip", "Activate <application>KAlarm</application>"));
     mKAlarmButton->setWhatsThis(xi18nc("@info:whatsthis", "Activate <application>KAlarm</application>"));
@@ -531,7 +532,7 @@ int MessageWindow::windowCount(bool excludeAlwaysHidden)
     int count = mWindowList.count();
     if (excludeAlwaysHidden)
     {
-        for (MessageWindow* win : std::as_const(mWindowList))
+        for (const MessageWindow* win : std::as_const(mWindowList))
         {
             if (win->mAlwaysHidden())
                 --count;
@@ -1231,15 +1232,6 @@ void MessageWindow::enableEditButton(bool enable)
         mEditButton->setEnabled(enable);
 }
 
-/******************************************************************************
-* Called when the KAlarm icon button in the message window is clicked.
-* Displays the main window, with the appropriate alarm selected.
-*/
-void MessageWindow::displayMainWindow()
-{
-    MessageDisplay::displayMainWindow();
-}
-
 /******************************************************************************
 * Check whether the message window should be modal, i.e. with title bar etc.
 * Normally this follows the Preferences setting, but if there is a full screen
